@@ -165,7 +165,7 @@ class WithNode(HierNode):
     def __init__(self, vars, *body):
         super(WithNode, self).__init__(body)
         self.vars_text = vars
-        self.vars = dict(var.split('=')
+        self.vars = dict(var.split('=', 1)
                          for var in vars.split(';'))
 
     def py(self):
@@ -298,7 +298,7 @@ class AttrNode(HierNode):
     def __iter__(self):
         if self.guard:
             new_body = IfNode(
-                'if %s' % self.guard,
+                self.guard,
                 AttrNode(self.attr, value=self.body, mode=self.mode))
             for x in new_body:
                 yield x
